Struct Cfgr1
#[repr(transparent)]pub struct Cfgr1(pub u32);Expand description
configuration register 1
Tuple Fields
0: u32Implementations
impl Cfgr1
impl Cfgr1
pub const fn mem_mode(&self) -> MemMode
pub const fn mem_mode(&self) -> MemMode
Memory mapping selection bits. This bitfield controlled by software selects the memory internally mapped at the address 0x0000_0000. Its reset value is determined by the boot mode configuration. Refer to Reference Manual section 2.5 for more details.
pub const fn set_mem_mode(&mut self, val: MemMode)
pub const fn set_mem_mode(&mut self, val: MemMode)
Memory mapping selection bits. This bitfield controlled by software selects the memory internally mapped at the address 0x0000_0000. Its reset value is determined by the boot mode configuration. Refer to Reference Manual section 2.5 for more details.
pub const fn pa11_rmp(&self) -> bool
pub const fn pa11_rmp(&self) -> bool
PA11 pin remapping This bit is set and cleared by software. When set, it remaps the PA11 pin to operate as PA9 GPIO port, instead as PA11 GPIO port.
pub const fn set_pa11_rmp(&mut self, val: bool)
pub const fn set_pa11_rmp(&mut self, val: bool)
PA11 pin remapping This bit is set and cleared by software. When set, it remaps the PA11 pin to operate as PA9 GPIO port, instead as PA11 GPIO port.
pub const fn pa12_rmp(&self) -> bool
pub const fn pa12_rmp(&self) -> bool
PA12 pin remapping This bit is set and cleared by software. When set, it remaps the PA12 pin to operate as PA10 GPIO port, instead as PA12 GPIO port.
pub const fn set_pa12_rmp(&mut self, val: bool)
pub const fn set_pa12_rmp(&mut self, val: bool)
PA12 pin remapping This bit is set and cleared by software. When set, it remaps the PA12 pin to operate as PA10 GPIO port, instead as PA12 GPIO port.
pub const fn set_ir_pol(&mut self, val: bool)
pub const fn set_ir_pol(&mut self, val: bool)
IR output polarity selection
pub const fn set_ir_mod(&mut self, val: u8)
pub const fn set_ir_mod(&mut self, val: u8)
IR Modulation Envelope signal selection.
pub const fn set_boosten(&mut self, val: bool)
pub const fn set_boosten(&mut self, val: bool)
I/O analog switch voltage booster enable
pub const fn ucpd1_strobe(&self) -> bool
pub const fn ucpd1_strobe(&self) -> bool
Strobe signal bit for UCPD1
pub const fn set_ucpd1_strobe(&mut self, val: bool)
pub const fn set_ucpd1_strobe(&mut self, val: bool)
Strobe signal bit for UCPD1
pub const fn ucpd2_strobe(&self) -> bool
pub const fn ucpd2_strobe(&self) -> bool
Strobe signal bit for UCPD2
pub const fn set_ucpd2_strobe(&mut self, val: bool)
pub const fn set_ucpd2_strobe(&mut self, val: bool)
Strobe signal bit for UCPD2
pub const fn i2c_p_bx_fmp(&self) -> u8
pub const fn i2c_p_bx_fmp(&self) -> u8
Fast Mode Plus (FM+) driving capability activation bits
pub const fn set_i2c_p_bx_fmp(&mut self, val: u8)
pub const fn set_i2c_p_bx_fmp(&mut self, val: u8)
Fast Mode Plus (FM+) driving capability activation bits
pub const fn set_i2c1_fmp(&mut self, val: bool)
pub const fn set_i2c1_fmp(&mut self, val: bool)
FM+ driving capability activation for I2C1
pub const fn set_i2c2_fmp(&mut self, val: bool)
pub const fn set_i2c2_fmp(&mut self, val: bool)
FM+ driving capability activation for I2C2
pub const fn i2c_p_ax_fmp(&self) -> u8
pub const fn i2c_p_ax_fmp(&self) -> u8
Fast Mode Plus (FM+) driving capability activation bits
pub const fn set_i2c_p_ax_fmp(&mut self, val: u8)
pub const fn set_i2c_p_ax_fmp(&mut self, val: u8)
Fast Mode Plus (FM+) driving capability activation bits